@@ -18,6 +18,8 @@ Plot <- R6::R6Class(
                           no_par             = FALSE,
                           xlim               = NULL,
                           ylim               = NULL,
+                          xlab               = NULL,
+                          ylab               = NULL,
                           legend             = TRUE,
                           log                = "",
                           use_colors         = TRUE,
@@ -29,7 +31,9 @@ Plot <- R6::R6Class(
                           legend_position    = "topleft",
                           legend_title       = NULL,
                           limit_agents       = NULL,
-                          limit_context      = NULL) {
+                          limit_context      = NULL,
+                          trunc_over_agents  = TRUE,
+                          trunc_per_agent    = TRUE) {
 
       self$history       <- history
 
@@ -71,6 +75,8 @@ Plot <- R6::R6Class(
         lwd                 = lwd,
         xlim                = xlim,
         ylim                = ylim,
+        xlab                = xlab,
+        ylab                = ylab,
         legend_labels       = legend_labels,
         legend_border       = legend_border,
         legend_position     = legend_position,
@@ -81,7 +87,9 @@ Plot <- R6::R6Class(
         traces_max          = traces_max,
         traces_alpha        = traces_alpha,
         smooth              = smooth,
-        rate                = rate
+        rate                = rate,
+        trunc_over_agents   = trunc_over_agents,
+        trunc_per_agent     = trunc_per_agent
       )
 
       invisible(recordPlot())
@@ -99,6 +107,8 @@ Plot <- R6::R6Class(
                        no_par             = FALSE,
                        xlim               = NULL,
                        ylim               = NULL,
+                       xlab               = NULL,
+                       ylab               = NULL,
                        legend             = TRUE,
                        use_colors         = TRUE,
                        log                = "",
@@ -110,7 +120,9 @@ Plot <- R6::R6Class(
                        legend_position    = "topleft",
                        legend_title       = NULL,
                        limit_agents       = NULL,
-                       limit_context      = NULL) {
+                       limit_context      = NULL,
+                       trunc_over_agents  = TRUE,
+                       trunc_per_agent    = TRUE) {
 
       self$history <- history
 
@@ -143,7 +155,9 @@ Plot <- R6::R6Class(
         traces              = traces,
         traces_max          = traces_max,
         traces_alpha        = traces_alpha,
-        smooth              = smooth
+        smooth              = smooth,
+        trunc_over_agents   = trunc_over_agents,
+        trunc_per_agent     = trunc_per_agent
       )
 
       invisible(recordPlot())
@@ -163,6 +177,8 @@ Plot <- R6::R6Class(
                        no_par             = FALSE,
                        xlim               = NULL,
                        ylim               = NULL,
+                       xlab               = NULL,
+                       ylab               = NULL,
                        legend             = TRUE,
                        use_colors         = TRUE,
                        log                = "",
@@ -175,7 +191,9 @@ Plot <- R6::R6Class(
                        legend_position    = "topleft",
                        legend_title       = NULL,
                        limit_agents       = NULL,
-                       limit_context      = NULL) {
+                       limit_context      = NULL,
+                       trunc_over_agents  = TRUE,
+                       trunc_per_agent    = TRUE) {
       self$history <- history
 
       if (regret) {
@@ -204,6 +222,8 @@ Plot <- R6::R6Class(
         lwd                 = lwd,
         xlim                = xlim,
         ylim                = ylim,
+        xlab                = xlab,
+        ylab                = ylab,
         legend_labels       = legend_labels,
         legend_border       = legend_border,
         legend_position     = legend_position,
@@ -215,7 +235,9 @@ Plot <- R6::R6Class(
         traces_max          = traces_max,
         traces_alpha        = traces_alpha,
         smooth              = smooth,
-        rate                = rate
+        rate                = rate,
+        trunc_over_agents   = trunc_over_agents,
+        trunc_per_agent     = trunc_per_agent
       )
 
       invisible(recordPlot())
@@ -230,6 +252,8 @@ Plot <- R6::R6Class(
                     interval           = 1,
                     xlim               = NULL,
                     ylim               = NULL,
+                    xlab               = NULL,
+                    ylab               = NULL,
                     legend_labels      = NULL,
                     legend_border      = NULL,
                     legend_position    = "bottomright",
@@ -256,11 +280,11 @@ Plot <- R6::R6Class(
 
       if(!is.null(limit_context)) {
         dt <- self$history$get_data_table(
-          limit_cols   = c("agent", "t", "choice", "sim", "context"),
+          limit_cols   = c("agent", "t", "choice", "sim", limit_context),
           limit_agents = limit_agents,
           interval     = interval
         )
-        dt <- dt[sapply(context,function(x)all(x[limit_context]==1))]
+        dt <- dt[dt[, Reduce(`|`, lapply(.SD, `==`, 1)),.SDcols = limit_context],]
       } else {
         dt <- self$history$get_data_table(
           limit_cols   = c("agent", "t", "choice", "sim"),
@@ -302,7 +326,10 @@ Plot <- R6::R6Class(
 
       eg                <- expand.grid(t = dt[sim == 1]$t, choice = seq(1.0, max_arm, 1))
       data              <- merge(data, eg, all = TRUE)
-      data[is.na(data)] <- 0.0
+      # turn NA into 0
+      for (j in seq_len(ncol(data)))
+        set(data,which(is.na(data[[j]])),j,0)
+
       data$dataum       <- ave(data$arm_count, data$t, FUN = cumsum)
       data$zero         <- 0.0
       min_ylim          <- 0
@@ -416,6 +443,8 @@ Plot <- R6::R6Class(
                        no_par              = FALSE,
                        xlim                = NULL,
                        ylim                = NULL,
+                       xlab                = NULL,
+                       ylab                = NULL,
                        interval            = 1,
                        color_step          = 1,
                        lty_step            = 1,
@@ -431,7 +460,9 @@ Plot <- R6::R6Class(
                        traces_alpha        = 0.3,
                        cum_average         = FALSE,
                        smooth              = FALSE,
-                       rate                = FALSE) {
+                       rate                = FALSE,
+                       trunc_over_agents   = TRUE,
+                       trunc_per_agent     = TRUE) {
 
       cum_flip <- FALSE
       if((line_data_name=="reward" || line_data_name=="regret") && isTRUE(cum_average)) {
@@ -458,7 +489,7 @@ Plot <- R6::R6Class(
         disp_data_name <- gsub("none", disp, disp_data_name)
         data <-
           self$history$get_cumulative_data(
-            limit_cols   = c("agent", "t", line_data_name, disp_data_name),
+            limit_cols   = c("agent", "t", "sims", line_data_name, disp_data_name),
             limit_agents = limit_agents,
             interval     = interval
           )
@@ -467,12 +498,28 @@ Plot <- R6::R6Class(
         disp <- NULL
         data <-
           self$history$get_cumulative_data(
-            limit_cols   = c("agent", "t", line_data_name),
+            limit_cols   = c("agent", "t", "sims", line_data_name),
             limit_agents = limit_agents,
             interval     = interval
           )
       }
 
+      agent_levels <- levels(droplevels(data$agent))
+      n_agents <- length(agent_levels)
+
+      # turn NA into 0
+      for (j in seq_len(ncol(data)))
+        data.table::set(data,which(is.na(data[[j]])),j,0)
+
+      if(isTRUE(trunc_per_agent))  {
+        data <- data[data$sims == max(data$sims)]
+      }
+
+      if(isTRUE(trunc_over_agents))  {
+        min_t_sim <- min(data[,max(t), by = c("agent")]$V1)
+        data <- data[t<=min_t_sim]
+      }
+
       if (!is.null(xlim)) {
         min_xlim <- xlim[1]
         max_xlim <- xlim[2]
@@ -481,9 +528,6 @@ Plot <- R6::R6Class(
         max_xlim <- data[, max(t)]
       }
 
-      agent_levels <- levels(droplevels(data$agent))
-      n_agents <- length(agent_levels)
-
       data.table::setorder(data, agent, t)
 
       if(cum_flip==TRUE) {
@@ -505,12 +549,11 @@ Plot <- R6::R6Class(
       if(!is.null(xlim)) data <- data[t>=xlim[1] & t<=xlim[2]]
 
       if(!is.null(limit_context)) {
-        data <- data[sapply(dt$context,function(x)all(x[limit_context]==1))]
+        data <- data[data[, Reduce(`|`, lapply(.SD, `==`, 1)),.SDcols = sel],]
       }
 
       data.table::setorder(data, agent, t)
 
-
       if (isTRUE(smooth)) {
         for (agent_name in agent_levels) {
           data[data$agent == agent_name, c("t", line_data_name) :=
@@ -651,9 +694,11 @@ Plot <- R6::R6Class(
       }
       axis(1)
       axis(2)
-      title(xlab = "Time step")
+      if (is.null(xlab)) xlab = "Time step"
+      title(xlab = xlab)
       if(isTRUE(plot_only_disp)) ylab_title <- paste0(ylab_title,": ",disp)
-      title(ylab = ylab_title)
+      if (is.null(ylab)) ylab = ylab_title
+      title(ylab = ylab)
       box()
       if (legend) {
         if (!is.null(legend_labels)) {
@@ -693,10 +738,10 @@ Plot <- R6::R6Class(
 
 #' Plot
 #'
-#' Generates plots from \code{History} data.
+#' Generates plots from \code{\link{History}} data.
 #'
 #' Usually not instantiated directly but invoked by calling the generic \code{plot(h)}, where \code{h}
-#' is an \code{History} class instance.
+#' is an \code{\link{History}} class instance.
 #'
 #' @name Plot
 #' @aliases average optimal arms do_plot gg_color_hue check_history_data
@@ -740,8 +785,7 @@ Plot <- R6::R6Class(
 #'      \code{(list , NULL)} Limit plotted agents to the agents in the list.
 #'   }
 #'   \item{\code{limit_context}}{
-#'      \code{(integer vector , NULL)} Only plots data of context(s) where vector equals 1 in
-#'      as.vector(context), excludes where 0 or unspecified.
+#'      \code{(character vector , NULL)} Only plots data where context feature name(s) in vector equal to one.
 #'   }
 #'   \item{\code{no_par}}{
 #'      \code{(logical, FALSE)} If no_par is TRUE, Plot() does not set or adjust plotting parameters itself.
@@ -813,6 +857,20 @@ Plot <- R6::R6Class(
 #'   \item{\code{lwd}}{
 #'      \code{(integer, 1)} Line width.
 #'   }
+#'   \item{\code{xlab}}{
+#'      \code{(character, NULL)} a title for the x axis
+#'   }
+#'   \item{\code{ylab}}{
+#'      \code{(character, NULL)} a title for the y axis
+#'   }
+#'   \item{\code{trunc_over_agents}}{
+#'      \code{(logical , TRUE)} Truncate the chart to the agent with the fewest time steps t.
+#'   }
+#'   \item{\code{trunc_per_agent}}{
+#'      \code{(logical , TRUE)} Truncate every agent's plot to the number of time steps that have been fully
+#'      simulated. That is, time steps for which the number of simulations equals the number defined in
+#'      \code{\link{Simulator}}'s \code{simulations} parameter.
+#'   }
 #'  }
 #'
 #'
