@@ -4,7 +4,8 @@ DependentObservationsBootstrappedBandit <- R6::R6Class(
   class = FALSE,
   private = list(
     S = NULL,
-    x = NULL
+    x = NULL,
+    rows = NULL
   ),
   public = list(
     class_name = "DependentObservationsBootstrappedBandit",
@@ -17,6 +18,7 @@ DependentObservationsBootstrappedBandit <- R6::R6Class(
       private$S[is.null(context[[1]]),`:=`(context = list(1))]
       self$arm_multiply <- TRUE
       private$S <- do.call("rbind", replicate(self$k, private$S, simplify = FALSE))
+      private$rows <- nrow(private$S)  # <- daar
     },
     post_initialization = function() {
       private$S <- private$S[sample(nrow(private$S),replace=TRUE)]
@@ -24,6 +26,8 @@ DependentObservationsBootstrappedBandit <- R6::R6Class(
       private$x <- apply(private$x, 2, jitter)
     },
     get_context = function(index) {
+      print(index)
+      if(index > private$rows) return(NULL)   # <- en daar ...
       context <- list(
         k      = self$k,
         d      = self$d,
